@@ -23,14 +23,15 @@ import unicodedata
 import time
 import re
 import six
+import string
 
 from beets import logging
 from beets.mediafile import MediaFile, UnreadableFileError
 from beets import plugins
 from beets import util
 from beets.util import bytestring_path, syspath, normpath, samefile, \
-    MoveOperation
-from beets.util.functemplate import Template
+    MoveOperation, lazy_property
+from beets.util.functemplate import template, Template
 from beets import dbcore
 from beets.dbcore import types
 import beets
@@ -375,13 +376,25 @@ class FormattedItemMapping(dbcore.db.FormattedMapping):
 
     def __init__(self, item, for_path=False):
         super(FormattedItemMapping, self).__init__(item, for_path)
-        self.album = item.get_album()
-        self.album_keys = []
+        self.item = item
+
+    @lazy_property
+    def all_keys(self):
+        return set(self.model_keys).union(self.album_keys)
+
+    @lazy_property
+    def album_keys(self):
+        album_keys = []
         if self.album:
             for key in self.album.keys(True):
-                if key in Album.item_keys or key not in item._fields.keys():
-                    self.album_keys.append(key)
-        self.all_keys = set(self.model_keys).union(self.album_keys)
+                if key in Album.item_keys \
+                        or key not in self.item._fields.keys():
+                    album_keys.append(key)
+        return album_keys
+
+    @lazy_property
+    def album(self):
+        return self.item.get_album()
 
     def _get(self, key):
         """Get the value for a key, either from the album or the item.
@@ -469,14 +482,15 @@ class Item(LibModel):
         'albumstatus':          types.STRING,
         'media':                types.STRING,
         'albumdisambig':        types.STRING,
+        'releasegroupdisambig': types.STRING,
         'disctitle':            types.STRING,
         'encoder':              types.STRING,
         'rg_track_gain':        types.NULL_FLOAT,
         'rg_track_peak':        types.NULL_FLOAT,
         'rg_album_gain':        types.NULL_FLOAT,
         'rg_album_peak':        types.NULL_FLOAT,
-        'r128_track_gain':      types.PaddedInt(6),
-        'r128_album_gain':      types.PaddedInt(6),
+        'r128_track_gain':      types.NullPaddedInt(6),
+        'r128_album_gain':      types.NullPaddedInt(6),
         'original_year':        types.PaddedInt(4),
         'original_month':       types.PaddedInt(2),
         'original_day':         types.PaddedInt(2),
@@ -564,7 +578,7 @@ class Item(LibModel):
 
     def clear(self):
         """Set all key/value pairs to None."""
-        for key in self._media_fields:
+        for key in self._media_tag_fields:
             setattr(self, key, None)
 
     def get_album(self):
@@ -609,7 +623,7 @@ class Item(LibModel):
 
         self.path = read_path
 
-    def write(self, path=None, tags=None):
+    def write(self, path=None, tags=None, id3v23=None):
         """Write the item's metadata to a media file.
 
         All fields in `_media_fields` are written to disk according to
@@ -621,6 +635,9 @@ class Item(LibModel):
         `tags` is a dictionary of additional metadata the should be
         written to the file. (These tags need not be in `_media_fields`.)
 
+        `id3v23` will override the global `id3v23` config option if it is
+        set to something other than `None`.
+
         Can raise either a `ReadError` or a `WriteError`.
         """
         if path is None:
@@ -628,6 +645,9 @@ class Item(LibModel):
         else:
             path = normpath(path)
 
+        if id3v23 is None:
+            id3v23 = beets.config['id3v23'].get(bool)
+
         # Get the data to write to the file.
         item_tags = dict(self)
         item_tags = {k: v for k, v in item_tags.items()
@@ -638,8 +658,7 @@ class Item(LibModel):
 
         # Open the file.
         try:
-            mediafile = MediaFile(syspath(path),
-                                  id3v23=beets.config['id3v23'].get(bool))
+            mediafile = MediaFile(syspath(path), id3v23=id3v23)
         except UnreadableFileError as exc:
             raise ReadError(path, exc)
 
@@ -655,14 +674,14 @@ class Item(LibModel):
             self.mtime = self.current_mtime()
         plugins.send('after_write', item=self, path=path)
 
-    def try_write(self, path=None, tags=None):
+    def try_write(self, *args, **kwargs):
         """Calls `write()` but catches and logs `FileOperationError`
         exceptions.
 
         Returns `False` an exception was caught and `True` otherwise.
         """
         try:
-            self.write(path, tags)
+            self.write(*args, **kwargs)
             return True
         except FileOperationError as exc:
             log.error(u"{0}", exc)
@@ -848,7 +867,7 @@ class Item(LibModel):
         if isinstance(path_format, Template):
             subpath_tmpl = path_format
         else:
-            subpath_tmpl = Template(path_format)
+            subpath_tmpl = template(path_format)
 
         # Evaluate the selected template.
         subpath = self.evaluate_template(subpath_tmpl, True)
@@ -903,34 +922,35 @@ class Album(LibModel):
         'artpath': PathType(True),
         'added':   DateType(),
 
-        'albumartist':        types.STRING,
-        'albumartist_sort':   types.STRING,
-        'albumartist_credit': types.STRING,
-        'album':              types.STRING,
-        'genre':              types.STRING,
-        'year':               types.PaddedInt(4),
-        'month':              types.PaddedInt(2),
-        'day':                types.PaddedInt(2),
-        'disctotal':          types.PaddedInt(2),
-        'comp':               types.BOOLEAN,
-        'mb_albumid':         types.STRING,
-        'mb_albumartistid':   types.STRING,
-        'albumtype':          types.STRING,
-        'label':              types.STRING,
-        'mb_releasegroupid':  types.STRING,
-        'asin':               types.STRING,
-        'catalognum':         types.STRING,
-        'script':             types.STRING,
-        'language':           types.STRING,
-        'country':            types.STRING,
-        'albumstatus':        types.STRING,
-        'albumdisambig':      types.STRING,
-        'rg_album_gain':      types.NULL_FLOAT,
-        'rg_album_peak':      types.NULL_FLOAT,
-        'r128_album_gain':    types.PaddedInt(6),
-        'original_year':      types.PaddedInt(4),
-        'original_month':     types.PaddedInt(2),
-        'original_day':       types.PaddedInt(2),
+        'albumartist':          types.STRING,
+        'albumartist_sort':     types.STRING,
+        'albumartist_credit':   types.STRING,
+        'album':                types.STRING,
+        'genre':                types.STRING,
+        'year':                 types.PaddedInt(4),
+        'month':                types.PaddedInt(2),
+        'day':                  types.PaddedInt(2),
+        'disctotal':            types.PaddedInt(2),
+        'comp':                 types.BOOLEAN,
+        'mb_albumid':           types.STRING,
+        'mb_albumartistid':     types.STRING,
+        'albumtype':            types.STRING,
+        'label':                types.STRING,
+        'mb_releasegroupid':    types.STRING,
+        'asin':                 types.STRING,
+        'catalognum':           types.STRING,
+        'script':               types.STRING,
+        'language':             types.STRING,
+        'country':              types.STRING,
+        'albumstatus':          types.STRING,
+        'albumdisambig':        types.STRING,
+        'releasegroupdisambig': types.STRING,
+        'rg_album_gain':        types.NULL_FLOAT,
+        'rg_album_peak':        types.NULL_FLOAT,
+        'r128_album_gain':      types.NullPaddedInt(6),
+        'original_year':        types.PaddedInt(4),
+        'original_month':       types.PaddedInt(2),
+        'original_day':         types.PaddedInt(2),
     }
 
     _search_fields = ('album', 'albumartist', 'genre')
@@ -969,6 +989,7 @@ class Album(LibModel):
         'country',
         'albumstatus',
         'albumdisambig',
+        'releasegroupdisambig',
         'rg_album_gain',
         'rg_album_peak',
         'r128_album_gain',
@@ -1027,6 +1048,12 @@ class Album(LibModel):
         if not old_art:
             return
 
+        if not os.path.exists(old_art):
+            log.error(u'removing reference to missing album art file {}',
+                      util.displayable_path(old_art))
+            self.artpath = None
+            return
+
         new_art = self.art_destination(old_art)
         if new_art == old_art:
             return
@@ -1119,7 +1146,7 @@ class Album(LibModel):
         image = bytestring_path(image)
         item_dir = item_dir or self.item_dir()
 
-        filename_tmpl = Template(
+        filename_tmpl = template(
             beets.config['art_filename'].as_str())
         subpath = self.evaluate_template(filename_tmpl, True)
         if beets.config['asciify_paths']:
@@ -1224,8 +1251,10 @@ def parse_query_parts(parts, model_cls):
         else:
             non_path_parts.append(s)
 
+    case_insensitive = beets.config['sort_case_insensitive'].get(bool)
+
     query, sort = dbcore.parse_sorted_query(
-        model_cls, non_path_parts, prefixes
+        model_cls, non_path_parts, prefixes, case_insensitive
     )
 
     # Add path queries to aggregate query.
@@ -1447,7 +1476,7 @@ class DefaultTemplateFunctions(object):
     @staticmethod
     def tmpl_title(s):
         """Convert a string to title case."""
-        return s.title()
+        return string.capwords(s)
 
     @staticmethod
     def tmpl_left(s, chars):
@@ -1503,17 +1532,24 @@ class DefaultTemplateFunctions(object):
         # Fast paths: no album, no item or library, or memoized value.
         if not self.item or not self.lib:
             return u''
-        if self.item.album_id is None:
+
+        if isinstance(self.item, Item):
+            album_id = self.item.album_id
+        elif isinstance(self.item, Album):
+            album_id = self.item.id
+
+        if album_id is None:
             return u''
-        memokey = ('aunique', keys, disam, self.item.album_id)
+
+        memokey = ('aunique', keys, disam, album_id)
         memoval = self.lib._memotable.get(memokey)
         if memoval is not None:
             return memoval
 
-        keys = keys or 'albumartist album'
-        disam = disam or 'albumtype year label catalognum albumdisambig'
+        keys = keys or beets.config['aunique']['keys'].as_str()
+        disam = disam or beets.config['aunique']['disambiguators'].as_str()
         if bracket is None:
-            bracket = '[]'
+            bracket = beets.config['aunique']['bracket'].as_str()
         keys = keys.split()
         disam = disam.split()
 
@@ -1525,7 +1561,7 @@ class DefaultTemplateFunctions(object):
             bracket_l = u''
             bracket_r = u''
 
-        album = self.lib.get_album(self.item)
+        album = self.lib.get_album(album_id)
         if not album:
             # Do nothing for singletons.
             self.lib._memotable[memokey] = u''
