@@ -23,8 +23,8 @@ from beets.plugins import BeetsPlugin
 __author__ = 'baobab@heresiarch.info'
 __version__ = '1.1'
 
-PATTERN_THE = u'^[the]{3}\s'
-PATTERN_A = u'^[a][n]?\s'
+PATTERN_THE = u'^[the]{3}\\s'
+PATTERN_A = u'^[a][n]?\\s'
 FORMAT = u'{0}, {1}'
 
 
@@ -93,8 +93,8 @@ class ThePlugin(BeetsPlugin):
             for p in self.patterns:
                 r = self.unthe(text, p)
                 if r != text:
+                    self._log.debug(u'\"{0}\" -> \"{1}\"', text, r)
                     break
-            self._log.debug(u'\"{0}\" -> \"{1}\"', text, r)
             return r
         else:
             return u''
