@@ -16,14 +16,16 @@ project = u'beets'
 copyright = u'2016, Adrian Sampson'
 
 version = '1.4'
-release = '1.4.7'
+release = '1.4.9'
 
 pygments_style = 'sphinx'
 
-# External links to the bug tracker.
+# External links to the bug tracker and other sites.
 extlinks = {
     'bug': ('https://github.com/beetbox/beets/issues/%s', '#'),
     'user': ('https://github.com/%s', ''),
+    'pypi': ('https://pypi.org/project/%s/', ''),
+    'stdlib': ('https://docs.python.org/3/library/%s.html', ''),
 }
 
 # Options for HTML output
