@@ -751,7 +751,7 @@ class ApplyTest(_common.TestCase, ApplyTestUtil):
         self.assertEqual(self.items[0].artist, 'artistNew')
         self.assertEqual(self.items[1].artist, 'artistNew')
 
-    def test_album_artist_overriden_by_nonempty_track_artist(self):
+    def test_album_artist_overridden_by_nonempty_track_artist(self):
         my_info = copy.deepcopy(self.info)
         my_info.tracks[0].artist = 'artist1!'
         my_info.tracks[1].artist = 'artist2!'
