@@ -17,7 +17,7 @@
 
 from __future__ import division, absolute_import, print_function
 
-from test._common import unittest
+import unittest
 from beetsplug import bucket
 from beets import config, ui
 
