@@ -16,63 +16,61 @@
 from __future__ import division, absolute_import, print_function
 
 from mock import patch
-from test._common import unittest
+import unittest
 from test.helper import TestHelper
 
 from beets.library import Item
 from beets import util
 
 
+@patch('beets.util.command_output')
 class KeyFinderTest(unittest.TestCase, TestHelper):
 
     def setUp(self):
         self.setup_beets()
         self.load_plugins('keyfinder')
-        self.patcher = patch('beets.util.command_output')
-        self.command_output = self.patcher.start()
 
     def tearDown(self):
         self.teardown_beets()
         self.unload_plugins()
-        self.patcher.stop()
 
-    def test_add_key(self):
+    def test_add_key(self, command_output):
         item = Item(path='/file')
         item.add(self.lib)
 
-        self.command_output.return_value = 'dbm'
+        command_output.return_value = 'dbm'
         self.run_command('keyfinder')
 
         item.load()
         self.assertEqual(item['initial_key'], 'C#m')
-        self.command_output.assert_called_with(
+        command_output.assert_called_with(
             ['KeyFinder', '-f', util.syspath(item.path)])
 
-    def test_add_key_on_import(self):
-        self.command_output.return_value = 'dbm'
+    def test_add_key_on_import(self, command_output):
+        command_output.return_value = 'dbm'
         importer = self.create_importer()
         importer.run()
 
         item = self.lib.items().get()
         self.assertEqual(item['initial_key'], 'C#m')
 
-    def test_force_overwrite(self):
+    def test_force_overwrite(self, command_output):
         self.config['keyfinder']['overwrite'] = True
 
         item = Item(path='/file', initial_key='F')
         item.add(self.lib)
 
-        self.command_output.return_value = 'C#m'
+        command_output.return_value = 'C#m'
         self.run_command('keyfinder')
 
         item.load()
         self.assertEqual(item['initial_key'], 'C#m')
 
-    def test_do_not_overwrite(self):
+    def test_do_not_overwrite(self, command_output):
         item = Item(path='/file', initial_key='F')
         item.add(self.lib)
 
-        self.command_output.return_value = 'dbm'
+        command_output.return_value = 'dbm'
         self.run_command('keyfinder')
 
         item.load()
