@@ -302,8 +302,8 @@ class MBAlbumInfoTest(_common.TestCase):
     def test_parse_disambig(self):
         release = self._make_release(None)
         d = mb.album_info(release)
-        self.assertEqual(d.albumdisambig,
-                         'RG_DISAMBIGUATION, R_DISAMBIGUATION')
+        self.assertEqual(d.albumdisambig, 'R_DISAMBIGUATION')
+        self.assertEqual(d.releasegroupdisambig, 'RG_DISAMBIGUATION')
 
     def test_parse_disctitle(self):
         tracks = [self._make_track('TITLE ONE', 'ID ONE', 100.0 * 1000.0),
@@ -371,7 +371,19 @@ class MBAlbumInfoTest(_common.TestCase):
         self.assertEqual(d.tracks[0].title, 'TITLE ONE')
         self.assertEqual(d.tracks[1].title, 'TITLE TWO')
 
-    def test_no_skip_audio_data_tracks(self):
+    def test_skip_audio_data_tracks_by_default(self):
+        tracks = [self._make_track('TITLE ONE', 'ID ONE', 100.0 * 1000.0),
+                  self._make_track('TITLE TWO', 'ID TWO', 200.0 * 1000.0)]
+        data_tracks = [self._make_track('TITLE AUDIO DATA', 'ID DATA TRACK',
+                                        100.0 * 1000.0)]
+        release = self._make_release(tracks=tracks, data_tracks=data_tracks)
+        d = mb.album_info(release)
+        self.assertEqual(len(d.tracks), 2)
+        self.assertEqual(d.tracks[0].title, 'TITLE ONE')
+        self.assertEqual(d.tracks[1].title, 'TITLE TWO')
+
+    def test_no_skip_audio_data_tracks_if_configured(self):
+        config['match']['ignore_data_tracks'] = False
         tracks = [self._make_track('TITLE ONE', 'ID ONE', 100.0 * 1000.0),
                   self._make_track('TITLE TWO', 'ID TWO', 200.0 * 1000.0)]
         data_tracks = [self._make_track('TITLE AUDIO DATA', 'ID DATA TRACK',
@@ -406,6 +418,7 @@ class MBAlbumInfoTest(_common.TestCase):
         self.assertEqual(d.tracks[1].title, 'TITLE TWO')
 
     def test_no_skip_video_tracks_if_configured(self):
+        config['match']['ignore_data_tracks'] = False
         config['match']['ignore_video_tracks'] = False
         tracks = [self._make_track('TITLE ONE', 'ID ONE', 100.0 * 1000.0),
                   self._make_track('TITLE VIDEO', 'ID VIDEO', 100.0 * 1000.0,
@@ -419,6 +432,7 @@ class MBAlbumInfoTest(_common.TestCase):
         self.assertEqual(d.tracks[2].title, 'TITLE TWO')
 
     def test_no_skip_video_data_tracks_if_configured(self):
+        config['match']['ignore_data_tracks'] = False
         config['match']['ignore_video_tracks'] = False
         tracks = [self._make_track('TITLE ONE', 'ID ONE', 100.0 * 1000.0),
                   self._make_track('TITLE TWO', 'ID TWO', 200.0 * 1000.0)]
