@@ -51,7 +51,7 @@ class MbsyncCliTest(unittest.TestCase, TestHelper):
 
         album_item = Item(
             album=u'old title',
-            mb_albumid=u'album id',
+            mb_albumid=u'81ae60d4-5b75-38df-903a-db2cfa51c2c6',
             mb_trackid=u'old track id',
             mb_releasetrackid=u'release track id',
             path=''
@@ -60,13 +60,14 @@ class MbsyncCliTest(unittest.TestCase, TestHelper):
 
         item = Item(
             title=u'old title',
-            mb_trackid=u'singleton track id',
+            mb_trackid=u'b8c2cf90-83f9-3b5f-8ccd-31fb866fcf37',
             path='',
         )
         self.lib.add(item)
 
         with capture_log() as logs:
             self.run_command('mbsync')
+
         self.assertIn('Sending event: albuminfo_received', logs)
         self.assertIn('Sending event: trackinfo_received', logs)
 
@@ -135,6 +136,63 @@ class MbsyncCliTest(unittest.TestCase, TestHelper):
         e = u"mbsync: Skipping singleton with no mb_trackid: 'old title'"
         self.assertEqual(e, logs[0])
 
+    def test_message_when_invalid(self):
+        config['format_item'] = u'$artist - $album - $title'
+        config['format_album'] = u'$albumartist - $album'
+
+        # Test album with invalid mb_albumid.
+        # The default format for an album include $albumartist so
+        # set that here, too.
+        album_invalid = Item(
+            albumartist=u'album info',
+            album=u'album info',
+            mb_albumid=u'a1b2c3d4',
+            path=''
+        )
+        self.lib.add_album([album_invalid])
+
+        # default format
+        with capture_log('beets.mbsync') as logs:
+            self.run_command('mbsync')
+        e = u'mbsync: Skipping album with invalid mb_albumid: ' + \
+            u'album info - album info'
+        self.assertEqual(e, logs[0])
+
+        # custom format
+        with capture_log('beets.mbsync') as logs:
+            self.run_command('mbsync', '-f', "'$album'")
+        e = u"mbsync: Skipping album with invalid mb_albumid: 'album info'"
+        self.assertEqual(e, logs[0])
+
+        # restore the config
+        config['format_item'] = u'$artist - $album - $title'
+        config['format_album'] = u'$albumartist - $album'
+
+        # Test singleton with invalid mb_trackid.
+        # The default singleton format includes $artist and $album
+        # so we need to stub them here
+        item_invalid = Item(
+            artist=u'album info',
+            album=u'album info',
+            title=u'old title',
+            mb_trackid=u'a1b2c3d4',
+            path='',
+        )
+        self.lib.add(item_invalid)
+
+        # default format
+        with capture_log('beets.mbsync') as logs:
+            self.run_command('mbsync')
+        e = u'mbsync: Skipping singleton with invalid mb_trackid: ' + \
+            u'album info - album info - old title'
+        self.assertEqual(e, logs[0])
+
+        # custom format
+        with capture_log('beets.mbsync') as logs:
+            self.run_command('mbsync', '-f', "'$title'")
+        e = u"mbsync: Skipping singleton with invalid mb_trackid: 'old title'"
+        self.assertEqual(e, logs[0])
+
 
 def suite():
     return unittest.TestLoader().loadTestsFromName(__name__)
