@@ -318,29 +318,30 @@ class ReadWriteTestBase(ArtTestMixin, GenreListTestMixin,
     """
 
     full_initial_tags = {
-        'title':       u'full',
-        'artist':      u'the artist',
-        'album':       u'the album',
-        'genre':       u'the genre',
-        'composer':    u'the composer',
-        'grouping':    u'the grouping',
-        'year':        2001,
-        'month':       None,
-        'day':         None,
-        'date':        datetime.date(2001, 1, 1),
-        'track':       2,
-        'tracktotal':  3,
-        'disc':        4,
-        'disctotal':   5,
-        'lyrics':      u'the lyrics',
-        'comments':    u'the comments',
-        'bpm':         6,
-        'comp':        True,
-        'mb_trackid':  '8b882575-08a5-4452-a7a7-cbb8a1531f9e',
-        'mb_albumid':  '9e873859-8aa4-4790-b985-5a953e8ef628',
-        'mb_artistid': '7cf0ea9d-86b9-4dad-ba9e-2355a64899ea',
-        'art':         None,
-        'label':       u'the label',
+        'title':             u'full',
+        'artist':            u'the artist',
+        'album':             u'the album',
+        'genre':             u'the genre',
+        'composer':          u'the composer',
+        'grouping':          u'the grouping',
+        'year':              2001,
+        'month':             None,
+        'day':               None,
+        'date':              datetime.date(2001, 1, 1),
+        'track':             2,
+        'tracktotal':        3,
+        'disc':              4,
+        'disctotal':         5,
+        'lyrics':            u'the lyrics',
+        'comments':          u'the comments',
+        'bpm':               6,
+        'comp':              True,
+        'mb_trackid':        '8b882575-08a5-4452-a7a7-cbb8a1531f9e',
+        'mb_releasetrackid': 'c29f3a57-b439-46fd-a2e2-93776b1371e0',
+        'mb_albumid':        '9e873859-8aa4-4790-b985-5a953e8ef628',
+        'mb_artistid':       '7cf0ea9d-86b9-4dad-ba9e-2355a64899ea',
+        'art':               None,
+        'label':             u'the label',
     }
 
     tag_fields = [
@@ -366,6 +367,7 @@ class ReadWriteTestBase(ArtTestMixin, GenreListTestMixin,
         'bpm',
         'comp',
         'mb_trackid',
+        'mb_releasetrackid',
         'mb_albumid',
         'mb_artistid',
         'art',
@@ -773,7 +775,7 @@ class MusepackTest(ReadWriteTestBase, unittest.TestCase):
     extension = 'mpc'
     audio_properties = {
         'length': 1.0,
-        'bitrate': 23458,
+        'bitrate': 24023,
         'format': u'Musepack',
         'samplerate': 44100,
         'bitdepth': 0,
@@ -871,7 +873,7 @@ class ApeTest(ReadWriteTestBase, ExtendedImageStructureTestMixin,
     extension = 'ape'
     audio_properties = {
         'length': 1.0,
-        'bitrate': 112040,
+        'bitrate': 112608,
         'format': u'APE',
         'samplerate': 44100,
         'bitdepth': 16,
@@ -883,7 +885,7 @@ class WavpackTest(ReadWriteTestBase, unittest.TestCase):
     extension = 'wv'
     audio_properties = {
         'length': 1.0,
-        'bitrate': 108744,
+        'bitrate': 109312,
         'format': u'WavPack',
         'samplerate': 44100,
         'bitdepth': 0,
@@ -895,7 +897,7 @@ class OpusTest(ReadWriteTestBase, unittest.TestCase):
     extension = 'opus'
     audio_properties = {
         'length': 1.0,
-        'bitrate': 57984,
+        'bitrate': 66792,
         'format': u'Opus',
         'samplerate': 48000,
         'bitdepth': 0,
