@@ -322,7 +322,7 @@ class ListenersTest(unittest.TestCase, TestHelper):
     @patch('beets.plugins.find_plugins')
     @patch('beets.plugins.inspect')
     def test_events_called(self, mock_inspect, mock_find_plugins):
-        mock_inspect.getargspec.return_value = None
+        mock_inspect.getargspec.args.return_value = None
 
         class DummyPlugin(plugins.BeetsPlugin):
             def __init__(self):
